@@ -3,15 +3,15 @@
  *  plugins/forced_prefs/setup.php -- Displays the main frameset
  *
  * SquirrelMail Forced Prefs Plugin
- * Copyright (C) 2004-2005 Tomas Kuliavas <tokul@users.sourceforge.net>
+ * Copyright (C) 2004-2006 Tomas Kuliavas <tokul@users.sourceforge.net>
  * This program is licensed under GPL. See COPYING for details
  *
  * Redirects to the login page.
  *
  * @package sm-plugins
  * @subpackage forced_prefs
- * @version $Id: index.php,v 1.3 2005/01/24 18:04:33 tokul Exp $
+ * @version $Id: index.php,v 1.4 2006/04/18 09:25:06 tokul Exp $
  */
-header("Location: ../../src/login.php\n\n");
+header("Location: ../../index.php\n\n");
 exit();
 ?>
